@@ -1,4 +1,4 @@
-# $Id: Image.pm,v 1.5 2006/08/22 13:04:01 rousse Exp $
+# $Id: Image.pm,v 1.2 2004/04/05 13:57:31 guillaume Exp $
 package WWW::Orphea::Image;
 
 =head1 NAME
@@ -19,9 +19,9 @@ sub new {
     my ($class, $agent, $content, $legend) = @_;
 
     my $self = bless {
-        _agent   => $agent,
-        _content => $content,
-        _legend  => $legend,
+	_agent   => $agent,
+	_content => $content,
+	_legend  => $legend,
     }, $class;
 
     return $self;
@@ -65,10 +65,6 @@ Optional parameters:
 
 Use $file as file name.
 
-=item dir => I<$directory>
-
-Use $directory as a directory path to save the file.  If only 'file' is specified, it will be saved in a path relative to the current working directory.
-
 =item base => I<$base>
 
 Use $base with .jpg extension added as file name.
@@ -97,19 +93,19 @@ sub _get_file {
 
     my $file;
     if ($args{file}) {
-        $file = $args{file};
+	$file = $args{file};
     } elsif ($args{base}) {
-        $file = $args{base} . '.jpg';
+	$file = $args{base} . '.jpg';
     } else {
-        $url =~ /([^\/]+)$/;
-        $file = $1;
+	$url =~ /([^\/]+)$/;
+	$file = $1;
     }
 
     my $dir;
     if ($args{dir}) {
-        $dir = $args{dir};
+	$dir = $args{dir};
     } else {
-        $dir = '.';
+	$dir = '.';
     }
 
     return $dir . '/' . $file;
@@ -117,7 +113,7 @@ sub _get_file {
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2004-2006, INRIA.
+Copyright (C) 2004, INRIA.
 
 This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
